@@ -26,5 +26,9 @@
 #endif
 // GAP headers
 #include "gap_all.h"  // for Obj, Int
+                      //
+#ifdef GAP410_OR_OLDER
+#include "compiled.h"  // FIXME Remove include when we don't support GAP 4.10
+#endif
 
 #endif  // DIGRAPHS_SRC_GAP_INCLUDES_H_
